@@ -58,6 +58,7 @@ class BookingController
         $name = get_field('name', $bookingId);
         $surname = get_field('surname', $bookingId);
         $paymentReference = get_field('payment_reference', $bookingId);
+
         switch ($status) {
             case 'paid':
                 $subject = 'Successful Booking for ' . $paymentReference;
@@ -68,24 +69,24 @@ class BookingController
                 $inboundReference = get_field('inbound_reference', $paymentReference);
                 $addOns = get_field('add_ons', $paymentReference);
 
-                $body = '<p>Dear '.$name.' '.$surname.'</p>';
-                $body .= '<p>Thank you for your placing your booking, below you will find your booking and journey details.</p>';
-                $body .= '<p>Booking for '.$name.' '.$surname.'.</p>';
-                $body .= '<p>Payment Reference: '.$paymentReference.'</p>';
+                $body = '<p>Dear ' . $name . ' ' . $surname . '</p><br>';
+                $body .= '<p>Thank you for your placing your booking, below you will find your booking and journey details.</p><br>';
+                $body .= '<p>Booking for ' . $name . ' ' . $surname . '.</p>';
+                $body .= '<p>Payment Reference: ' . $paymentReference . '</p>';
                 $body .= '<p>Tickets:</p>';
                 foreach ($tickets as $ticket) {
-                    $body .= $ticket['ticket_type'].', Quantity: '.$ticket['quantity'];
+                    $body .= '<p>' . $ticket['ticket_type'] . ', Quantity: ' . $ticket['quantity'] . '<p><br>';
                 }
-                $body .= 'Journey: ' . $outboundJourney . 'Reference: '.$outboundReference;
+                $body .= '<p>Journey: ' . $outboundJourney . '<br>Reference: ' . $outboundReference . '</p>';
                 if ($inboundJourney) {
-                    $body .= 'Return Journey: ' . $inboundJourney . 'Reference: '.$inboundReference;
+                    $body .= '<p>Return Journey: ' . $inboundJourney . '<br>Reference: ' . $inboundReference . '</p>';
                 }
-                $body .= 'Add-ons: '.$addOns;
+                $body .= '<p>Add-ons:<br> ' . $addOns . '<p>';
                 break;
             case 'failed':
-                $subject = 'Unsuccessful Booking for ' . $paymentReference;
-                $body = 'Unfortunately payment was not succesful for reference: '.$paymentReference;
-                $body .= 'Please try again or contact 0123456789 or info@xploremore.co.uk';
+                $subject = '<p>Unsuccessful Booking for ' . $paymentReference . '</p>';
+                $body = '<p>Unfortunately payment was not succesful for reference: ' . $paymentReference . '</p>';
+                $body .= '<p>Please try again or contact <a href="tel:01382 340006">01382 340006</a> or <a href="mailto:XploreMore@nationalexpress.com">XploreMore@nationalexpress.com</a></p>';
                 break;
         }
 
