@@ -3,7 +3,9 @@
 * Template Name: Confirmation Template
 */
 
-include(__DIR__.'/header.php');
+include(__DIR__.'/header.php');?>
+<WPDISPLAY ITEM=banner>
+<?php
 XploreBooking\Controller\BookingController::handleWorldPay();
 include(__DIR__.'/footer.php');
 
